# RankGun V2.1.0

![Tests](https://github.com/Noah-Haf/RankGunModule/actions/workflows/tests.yml/badge.svg)

An API wrapper made for the RankGun API.

Make for [rankgun](https://rankgun.works), read the [docs](https://docs.rankgun.works)!

## Development

Run `pre-commit install` to set up the git hook scripts.
